==> apache-tinkerpop-3.5.7-src.zip: tinkerpop-3.5.7/gremlin-dotnet/src/Gremlin.Net/Structure/IO/GraphBinary/Types/TraverserSerializer.cs <==
﻿#region License

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#endregion

using System.IO;
using System.Threading;
using System.Threading.Tasks;
using Gremlin.Net.Process.Traversal;

namespace Gremlin.Net.Structure.IO.GraphBinary.Types
{
    /// <summary>
    /// A <see cref="Traverser"/> serializer.
    /// </summary>
    public class TraverserSerializer : SimpleTypeSerializer<Traverser>
    {
        /// <summary>
        ///     Initializes a new instance of the <see cref="TraverserSerializer" /> class.
        /// </summary>
        public TraverserSerializer() : base(DataType.Traverser)
        {
        }

        /// <inheritdoc />
        protected override async Task WriteValueAsync(Traverser value, Stream stream, GraphBinaryWriter writer,
            CancellationToken cancellationToken = default)
        {
            await writer.WriteValueAsync(value.Bulk, stream, false, cancellationToken).ConfigureAwait(false);
            await writer.WriteAsync(value.Object, stream, cancellationToken).ConfigureAwait(false);
        }

        /// <inheritdoc />
        protected override async Task<Traverser> ReadValueAsync(Stream stream, GraphBinaryReader reader,
            CancellationToken cancellationToken = default)
        {
            var bulk = (long)await reader.ReadValueAsync<long>(stream, false, cancellationToken).ConfigureAwait(false);
            var v = await reader.ReadAsync(stream, cancellationToken).ConfigureAwait(false);
            return new Traverser(v, bulk);
        }
    }
}

==> apache-tinkerpop-3.6.0-src.zip: tinkerpop-3.6.0/gremlin-dotnet/src/Gremlin.Net/Structure/IO/GraphBinary/Types/TraverserSerializer.cs <==
﻿#region License

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#endregion

using System.IO;
using System.Threading.Tasks;
using Gremlin.Net.Process.Traversal;

namespace Gremlin.Net.Structure.IO.GraphBinary.Types
{
    /// <summary>
    /// A <see cref="Traverser"/> serializer.
    /// </summary>
    public class TraverserSerializer : SimpleTypeSerializer<Traverser>
    {
        /// <summary>
        ///     Initializes a new instance of the <see cref="TraverserSerializer" /> class.
        /// </summary>
        public TraverserSerializer() : base(DataType.Traverser)
        {
        }

        /// <inheritdoc />
        protected override async Task WriteValueAsync(Traverser value, Stream stream, GraphBinaryWriter writer)
        {
            await writer.WriteValueAsync(value.Bulk, stream, false).ConfigureAwait(false);
            await writer.WriteAsync(value.Object, stream).ConfigureAwait(false);
        }

        /// <inheritdoc />
        protected override async Task<Traverser> ReadValueAsync(Stream stream, GraphBinaryReader reader)
        {
            var bulk = (long) await reader.ReadValueAsync<long>(stream, false).ConfigureAwait(false);
            var v = await reader.ReadAsync(stream).ConfigureAwait(false);
            return new Traverser(v, bulk);
        }
    }
}
